@@ -118,6 +118,7 @@ static void download_dif_item(DifItem* dif_item, GList* next_dif_items) {
 	Data* data;
 	GstBus* bus;
 	GstElement* src;
+	GstElement* queue;
 	GstElement* sink;
 	GstElement* decodebin;
 	GstElement* wavenc;
@@ -139,6 +140,8 @@ static void download_dif_item(DifItem* dif_item, GList* next_dif_items) {
 	g_free(uri);
 	g_free(s);
 
+	queue = gst_element_factory_make("queue", NULL);
+
 	decodebin = gst_element_factory_make("decodebin", NULL);
 	wavenc = gst_element_factory_make("wavenc", NULL);
 	g_signal_connect(decodebin, "new-decoded-pad", G_CALLBACK(on_new_decoded_pad), wavenc);
@@ -146,8 +149,8 @@ static void download_dif_item(DifItem* dif_item, GList* next_dif_items) {
 	sink = gst_element_factory_make("filesink", NULL);
 	g_object_set(sink, "location", data->path, NULL);
 	
-	gst_bin_add_many(GST_BIN(data->pipeline), src, decodebin, wavenc, sink, NULL);
-	gst_element_link(src, decodebin);
+	gst_bin_add_many(GST_BIN(data->pipeline), src, queue, decodebin, wavenc, sink, NULL);
+	gst_element_link_many(src, queue, decodebin, NULL);
 	gst_element_link(wavenc, sink);
 
 	gst_element_set_state(data->pipeline, GST_STATE_PLAYING); 
@@ -212,6 +215,8 @@ int main(int argc, char** argv) {
 	GtkWidget* dialog;
 	GtkWidget* label;
 
+	nice(1);
+
 	if (argc != 5) {
 		g_printerr("Usage: %s <dif_file> <root_url> <root_path> <duration_cache>\n", (argc > 0 ? argv[0] : "jammo-loader"));
 		
